/*
 *
 * * Copyright (c). 2012, Wyse Technology Inc.
 *
 * * All rights reserved.
 *
 * * You may not remove any Wyse logo, trademark or security lock.
 *
 * */

#ifdef CONFIG_VFAT
#include "system.h"
#include "sys/errno.h"
#include "charset.h"

static int
ucs_be_mbtowc (wchar_t *pwc, const unsigned char *s, int n)
{
	int i;
	unsigned char *dst;

	if (n >= sizeof(wchar_t)) {

		dst = (unsigned char *)pwc;

		switch(sizeof(wchar_t)) {
		case 4:
			*dst++ = s[3];
			*dst++ = s[2];
		case 2:
			*dst++ = s[1];
			*dst = s[0];
			break;
		default:
			return RET_ILSEQ;
		}

		return sizeof(wchar_t);
	}
	return RET_TOOSMALL;
}

static int
ucs_be_wctomb (unsigned char *r, wchar_t wc, int n)
{
	int i;

	if (n >= sizeof(wchar_t)) {

		switch(sizeof(wchar_t)) {
                case 4:
                        *r++ = (unsigned char)((wc >> 24)&0xff);
                        *r++ = (unsigned char)((wc >> 16)&0xff);
                case 2:
			*r++ = (unsigned char)((wc >> 8)&0xff);
			*r = (unsigned char)(wc&0xff);
                        break;
                default:
                        return RET_ILSEQ;
                }

                return sizeof(wchar_t);
	}

	return RET_TOOSMALL;
}

static int
ucs_le_mbtowc (wchar_t *pwc, const unsigned char *s, int n)
{
	if (n >= sizeof(wchar_t)) {
		*pwc = *(wchar_t *)s;
		return sizeof(wchar_t);
	}

	return RET_TOOSMALL;
}

static int
ucs_le_wctomb (unsigned char *r, wchar_t wc, int n)
{
	if (n >= sizeof(wchar_t)) {
		*(wchar_t *)r = wc;
		return sizeof(wchar_t);
	}

	return RET_TOOSMALL;
}

static struct ConvFuncTab conv_ucs_be = {
	.charset = "ucs2_be",
	.alias = "unicode_be",
	.mbtowc = ucs_be_mbtowc,
	.wctomb = ucs_be_wctomb,
};

static struct ConvFuncTab conv_ucs_le = {
	.charset = "ucs2_le",
        .alias = "unicode_le",
        .mbtowc = ucs_le_mbtowc,
        .wctomb = ucs_le_wctomb,
};

int
addConv_ucs_be(void)
{
	return addConvTab(&conv_ucs_be);
}

int
addConv_ucs_le(void)
{
	return addConvTab(&conv_ucs_le);
}

#endif
